@@ -127,10 +127,18 @@ class ModelThemes(ModelTemplate):
         self.model, self.binary = self.load_model(path, binary_path)
         self.pre_process = True
 
+    def set_cpu_predictor(self, model):
+        for model_index in range(len(model.estimators_)):
+            booster = model.estimators_[model_index].get_booster()
+            booster.set_param({'predictor':'cpu_predictor' })
+            model.estimators_[model_index].booster = booster
+        return model
+
     def load_model(self, path, binary_path):
 
         model_file = open(path, "rb")
         model = pickle.loads(model_file.read())
+        model = self.set_cpu_predictor(model)
         model_file.close()
 
         if binary_path:
